# -*- coding: utf-8 -*-
#
# Configuration file for the Sphinx documentation builder.
#
# This file does only contain a selection of the most common options. For a
# full list see the documentation:
# http://www.sphinx-doc.org/en/master/config

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
# import os
# import sys
# sys.path.insert(0, os.path.abspath('.'))
from sphinx_gallery.sorting import FileNameSortKey

import matplotlib
matplotlib.use('agg')

# Copy the changelog from package root dir to doc/source
import shutil
shutil.copy('../../changelog.md', 'changelog.md')

import pathlib
import sys

# Build citations for website
doc_loc = (pathlib.Path(__file__).parent.parent / 'source').resolve()
sys.path.append(str(doc_loc))

from parse_lib import build_citations
build_citations()

# Import EMD itself
source_loc = (pathlib.Path(__file__).parent.parent.parent).resolve()
sys.path.append(str(source_loc))
import emd


# -- Project information -----------------------------------------------------

project = 'emd'
copyright = '2019, Andrew Quinn'
author = 'Andrew Quinn'

# The short X.Y version
from importlib.metadata import version as get_version
release: str = get_version("emd")
# for example take major/minor
version: str = ".".join(release.split('.')[:2])


# -- General configuration ---------------------------------------------------

# If your documentation needs a minimal Sphinx version, state it here.
#
# needs_sphinx = '1.0'

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    'sphinx.ext.autodoc',
    'sphinx.ext.autosummary',
    'sphinx.ext.todo',
    'sphinx.ext.coverage',
    'sphinx.ext.imgmath',
    'sphinx.ext.ifconfig',
    'sphinx.ext.viewcode',
    'sphinx.ext.githubpages',
    'sphinx_copybutton',
    'sphinx_design',
    'sphinx_gallery.gen_gallery',
    'numpydoc',
    'myst_parser'
]

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# The suffix(es) of source filenames.
# You can specify multiple suffix as a list of string:
#
# source_suffix = ['.rst', '.md']
source_suffix = '.rst'

# The master toctree document.
master_doc = 'index'

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
language = 'en'

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path .
exclude_patterns = []

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = 'sphinx'


autodoc_default_flags = ['members']
autosummary_generate = True

panels_add_bootstrap_css = False


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
#html_theme = 'sphinx_rtd_theme'

#html_theme = 'bootstrap'
#html_theme_path = sphinx_bootstrap_theme.get_html_theme_path()
html_theme = "pydata_sphinx_theme"

html_css_files = [
    "https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.1.1/css/all.min.css"
]

# Theme options are theme-specific and customize the look and feel of a theme
# further.  For a list of options available for each theme, see the
# documentation.
#
# html_theme_options = {}
html_theme_options = {
  # Navbar
  "icon_links": [{"name": "PyPI",
                   "url": "https://pypi.org/project/emd",
                   "icon": "fas fa-box"},
                 {"name": "GitLab",
                  "url": 'https://gitlab.com/emd-dev/emd',
                  "icon": 'fa-brands fa-gitlab'}],
  "icon_links_label": "Quick Links",

  "navbar_start": ["navbar-logo"],
  "navbar_center": ["navbar-nav"],
  "navbar_end": [ "version-switcher", "navbar-icon-links"],
  "navbar_persistent": ["search-button"],

  "switcher": {
    "json_url": "https://emd.readthedocs.io/en/79-bump-version-to-v0-6-0/_static/switcher.json",
    "version_match": version,
  },

  "header_links_before_dropdown": 6,
  # General config
  "collapse_navigation": True,
}

html_logo = "_static/emd_logo.png"

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

# Custom sidebar templates, must be a dictionary that maps document names
# to template names.
#
# The default sidebars (for documents that don't match any pattern) are
# defined by theme itself.  Builtin themes are using these templates by
# default: ``['localtoc.html', 'relations.html', 'sourcelink.html',
# 'searchbox.html']``.
#
# html_sidebars = {}

# Sidebars for tutorial pages only
#html_sidebars = {'emd_tutorials/*/emd_tutorial*': ['localtoc.html'],
#                 'api*': ['localtoc.html']}


# -- Options for HTMLHelp output ---------------------------------------------

# Output file base name for HTML help builder.
htmlhelp_basename = 'emddoc'


# -- Options for LaTeX output ------------------------------------------------

latex_elements = {
    # The paper size ('letterpaper' or 'a4paper').
    #
    # 'papersize': 'letterpaper',

    # The font size ('10pt', '11pt' or '12pt').
    #
    # 'pointsize': '10pt',

    # Additional stuff for the LaTeX preamble.
    #
    # 'preamble': '',

    # Latex figure (float) alignment
    #
    # 'figure_align': 'htbp',
}

# Grouping the document tree into LaTeX files. List of tuples
# (source start file, target name, title,
#  author, documentclass [howto, manual, or own class]).
latex_documents = [
    (master_doc, 'emd.tex', 'emd Documentation',
     'Andrew Quinn', 'manual'),
]


# -- Options for manual page output ------------------------------------------

# One entry per manual page. List of tuples
# (source start file, name, description, authors, manual section).
man_pages = [
    (master_doc, 'emd', 'emd Documentation',
     [author], 1)
]


# -- Options for Texinfo output ----------------------------------------------

# Grouping the document tree into Texinfo files. List of tuples
# (source start file, target name, title, author,
#  dir menu entry, description, category)
texinfo_documents = [
    (master_doc, 'emd', 'emd Documentation',
     author, 'emd', 'One line description of project.',
     'Miscellaneous'),
]


# -- Options for Epub output -------------------------------------------------

# Bibliographic Dublin Core info.
epub_title = project
epub_author = author
epub_publisher = author
epub_copyright = copyright

# The unique identifier of the text. This can be a ISBN number
# or the project homepage.
#
# epub_identifier = ''

# A unique identification for the text.
#
# epub_uid = ''

# A list of files that should not be packed into the epub file.
epub_exclude_files = ['search.html']


# -- Extension configuration -------------------------------------------------

sphinx_gallery_conf = {
     'examples_dirs': 'tutorials',
     'gallery_dirs': 'emd_tutorials',  # path to where to save gallery generated output
     'filename_pattern': '/emd_tutorial_',
     'within_subsection_order': FileNameSortKey,
     'capture_repr': ('_repr_html_', '__repr__', '__str__'),
}

# -- Options for todo extension ----------------------------------------------

# If true, `todo` and `todoList` produce output, else they produce nothing.
todo_include_todos = True


# -- Options for sphinx_bootstrap

# -- Options for custom CSS
# https://stackoverflow.com/a/37980230


def setup(app):
    app.add_css_file('css/emd_custom.css')  # may also be an URL
